package com.uas.platform.oos.core.oos;

import com.amazonaws.ClientConfiguration;
import com.amazonaws.auth.PropertiesCredentials;
import com.amazonaws.services.s3.AmazonS3;
import com.amazonaws.services.s3.AmazonS3Client;
import com.uas.platform.oos.core.exception.ClientFailedException;
import com.uas.platform.oos.core.oos.client.OosClientHelper;
import java.io.IOException;
import java.io.InputStream;

/**
 * Abstract class provides method to create AmazonS3 instance.
 *
 * @author huxz
 */
public abstract class AbstractClient {

  /**
   * OOS endpoint.
   */
  public static final String OOS_ENDPOINT = "oos-gz.ctyunapi.cn";

  /**
   * OOS credentials properties file name.
   */
  private static final String CREDENTIALS_PROP_NAME = "OOSCredentials.properties";

  /**
   * Default Class Path of OOS credential properties.
   */
  private static final String CREDENTIALS_CLASS_PATH = "/" + CREDENTIALS_PROP_NAME;

  /**
   * Create a AmazonS3 instance, and configure it using default constants.
   */
  protected static AmazonS3 getClient() {

    // Load OOS credentials from class path.
    InputStream stream = OosClientHelper.class.getResourceAsStream(CREDENTIALS_CLASS_PATH);
    if (stream == null) {
      throw new IllegalStateException("Can't find properties " + CREDENTIALS_PROP_NAME);
    }

    // Create ClientConfiguration instance for configuring retry.
    ClientConfiguration configuration = new ClientConfiguration();
    configuration.setMaxErrorRetry(3);
    configuration.setConnectionTimeout(30 * 1000);
    configuration.setSocketTimeout(30 * 1000);

    AmazonS3 client;
    try {
      client = new AmazonS3Client(new PropertiesCredentials(stream), configuration);
      client.setEndpoint("https://" + OOS_ENDPOINT);
    } catch (IOException e) {
      throw new ClientFailedException("Failed to create AmazonS3 client ", e);
    }
    return client;
  }
}
