package com.uas.platform.oos.core.oos;

import com.amazonaws.services.s3.model.S3ObjectInputStream;
import java.io.File;
import java.util.Map;
import org.springframework.web.multipart.MultipartFile;

/**
 * Abstract interface defines basic operations of file.
 *
 * @author huxz
 */
public interface FileOperations {

  /**
   * Upload local file to OOS.
   *
   * @param bucketName  bucket name
   * @param file  local file to be uploaded
   * @return  path of file uploaded
   */
  String upload(String bucketName, File file);

  /**
   * Upload file from data of form to OOS.
   *
   * @param bucketName  bucket name
   * @param multiFile file inside form data
   * @return  path of file uploaded
   */
  String upload(String bucketName, MultipartFile multiFile);

  /**
   * Upload remote file to OOS.
   *
   * @param bucketName  bucket name
   * @param url link of remote file
   * @return  path of file uploaded
   */
  String upload(String bucketName, String url);

  /**
   * Download file from OOS.
   *
   * @param url the url of file on OOS
   * @return  InputStream of remote file
   */
  S3ObjectInputStream download(String url);

  /**
   * Delete file on OOS.
   *
   * @param url the url of file on OOS
   */
  void delete(String url);

  /**
   * Gain file metadata from OOS.
   *
   * @param url the url of file on OOS
   * @return metadata of the file
   */
  Map<String, Object> showMetadata(String url);

}
