package com.uas.platform.oos.core.util;

import com.fasterxml.jackson.core.JsonProcessingException;
import com.fasterxml.jackson.databind.JavaType;
import com.fasterxml.jackson.databind.ObjectMapper;
import java.io.IOException;
import java.util.ArrayList;
import java.util.Collections;
import java.util.List;
import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

/**
 * Jackson Util class.
 *
 * @author huxz
 */
@SuppressWarnings("unused")
public final class JacksonUtils {

  private static final Log logger = LogFactory.getLog(JacksonUtils.class);

  private static final String EMPTY_JSON = "{}";

  private static ObjectMapper objectMapper;

  /**
   * 把JSON文本parse为JavaBean.
   */
  public static <T> T fromJson(String text, Class<T> clazz) {
    if (objectMapper == null) {
      objectMapper = new ObjectMapper();
    }
    try {
      return objectMapper.readValue(text, clazz);
    } catch (IOException e) {
      logger.error("Read value failed", e);
    }
    return null;
  }

  /**
   * 把JSON文本parse成JavaBean集合.
   */
  public static <T> List<T> fromJsonArray(String text, Class<T> clazz) {
    if (objectMapper == null) {
      objectMapper = new ObjectMapper();
    }
    JavaType javaType = objectMapper.getTypeFactory()
        .constructParametricType(ArrayList.class, clazz);
    try {
      return objectMapper.readValue(text, javaType);
    } catch (IOException e) {
      logger.error("Read value failed", e);
    }
    return Collections.emptyList();
  }

  /**
   * 将JavaBean序列化为JSON文本.
   */
  public static String toJson(Object object) {
    if (objectMapper == null) {
      objectMapper = new ObjectMapper();
    }
    try {
      return objectMapper.writeValueAsString(object);
    } catch (JsonProcessingException e) {
      logger.error("Process json string failed", e);
    }
    return EMPTY_JSON;
  }
}
