package com.uas.platform.oos.dashboard.service;

import com.amazonaws.services.s3.model.S3ObjectInputStream;
import org.springframework.web.multipart.MultipartFile;

/**
 * A service of uploading file or downloading files.
 *
 * @author huxz
 */
public interface FileOperationService {

  /**
   * Upload a file to OOS.
   *
   * @param bucketName    the name of bucket
   * @param file          the uploaded file
   * @return path of the file
   */
  String uploadFileToRemote(String bucketName, MultipartFile file);

  /**
   * Upload a remote file to OOS.
   *
   * @param bucketName    the name of bucket
   * @param url           the remote file url
   * @return path of this url
   */
  String uploadRemoteFileToOos(String bucketName, String url);

  /**
   * Download files from OOS.
   *
   * @param url link of file on OOS
   * @return file input steam
   */
  S3ObjectInputStream download(String url);

  /**
   * Delete file on OOS.
   *
   * @param url link of file on OOS
   * @return  true, if success
   */
  boolean delete(String url);
}
