package com.uas.platform.oos.dashboard.service.impl;

import static com.uas.platform.oos.core.validate.ArgumentValidate.assertParameterNotNull;
import static com.uas.platform.oos.core.validate.ArgumentValidate.assertStringNotEmpty;

import com.amazonaws.services.s3.model.S3ObjectInputStream;
import com.uas.platform.oos.core.oos.client.OosClientHelper;
import com.uas.platform.oos.dashboard.service.FileOperationService;
import org.springframework.stereotype.Service;
import org.springframework.web.multipart.MultipartFile;

/**
 * Basic Java Bean implementation of {@code FileOperationService}.
 *
 * @author huxz
 */
@Service
public class FileOperationServiceImpl implements FileOperationService {

  @Override
  public String uploadFileToRemote(String bucketName, MultipartFile file) {
    assertStringNotEmpty(bucketName, "Bucket name must be non-empty");
    assertParameterNotNull(file, "Can't transfer an empty file to OOS");

    OosClientHelper helper = new OosClientHelper();
    return helper.upload(bucketName, file);
  }

  @Override
  public String uploadRemoteFileToOos(String bucketName, String url) {
    assertStringNotEmpty(bucketName, "Bucket name must be non-empty");
    assertStringNotEmpty(url, "Remote file url must be non-empty");

    OosClientHelper helper = new OosClientHelper();
    return helper.upload(bucketName, url);
  }

  @Override
  public S3ObjectInputStream download(String url) {
    assertStringNotEmpty(url, "Remote file url must be non-empty");

    OosClientHelper helper = new OosClientHelper();
    return helper.download(url);
  }

  @Override
  public boolean delete(String url) {
    assertStringNotEmpty(url, "Remote file url must be non-empty");

    OosClientHelper helper = new OosClientHelper();
    helper.delete(url);
    return true;
  }
}
