package com.uas.platform.oos.migration.api;

import com.uas.platform.oos.core.common.ResultBean;
import com.uas.platform.oos.migration.entity.OperationResult;
import com.uas.platform.oos.migration.service.MigrationFileService;
import com.uas.platform.oos.migration.service.impl.MigrationFileServiceImpl.MigrationStatistic;
import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.domain.Pageable;
import org.springframework.data.web.PageableDefault;
import org.springframework.http.MediaType;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

@RestController
@RequestMapping(value = "/api/file/migration")
public class MigrationController {

  private final MigrationFileService migrationFileService;

  @Autowired
  public MigrationController(
      MigrationFileService migrationFileService) {
    this.migrationFileService = migrationFileService;
  }

  @PostMapping(value = "//create-records", produces = MediaType.APPLICATION_JSON_UTF8_VALUE)
  public ResultBean<Long> createMigrationRecords(String tableName, String fieldName) {
    return new ResultBean<>(migrationFileService.createMigrationFileLog(tableName, fieldName));
  }

  @GetMapping(value = "//migrate-statistic", produces = MediaType.APPLICATION_JSON_UTF8_VALUE)
  public ResultBean<OperationResult> gainStatisticsForMigration(String tableName, String fieldName) {
    return new ResultBean<>(migrationFileService.gainStatisticsForMigration(tableName, fieldName));
  }

  @PostMapping(value = "//move-file", produces = MediaType.APPLICATION_JSON_UTF8_VALUE)
  public ResultBean<Long> moveFileToOos(@PageableDefault(size = 200) Pageable pageable) {
    return new ResultBean<>(migrationFileService.migrateFileToOos(pageable));
  }

  /**
   * gain statistic After migrated.
   */
  @GetMapping(value = "//migration-statistic", produces = MediaType.APPLICATION_JSON_UTF8_VALUE)
  public ResultBean<List<MigrationStatistic>> gainStatisticsForMovingFile() {
    return new ResultBean<>(migrationFileService.gainStatisticsForMovingFile());
  }

  @GetMapping(value = "//gain-fields", produces = MediaType.APPLICATION_JSON_UTF8_VALUE)
  public ResultBean<List<String>> gainFieldsWillMigrate() {
    return new ResultBean<>(migrationFileService.gainFieldsWillMigrate());
  }

  @PutMapping(value = "//sync-links", produces = MediaType.APPLICATION_JSON_UTF8_VALUE)
  public ResultBean<Long> syncResourceLink(String tableName, String fieldName) {
    return new ResultBean<>(migrationFileService.syncResourceLink(tableName, fieldName));
  }
}
