package com.uas.platform.oos.migration.entity;

import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonInclude.Include;
import com.uas.platform.oos.core.util.JacksonUtils;
import java.util.Date;
import javax.persistence.Column;
import javax.persistence.Entity;
import javax.persistence.EnumType;
import javax.persistence.Enumerated;
import javax.persistence.GeneratedValue;
import javax.persistence.GenerationType;
import javax.persistence.Id;
import javax.persistence.Table;

/**
 * store to be migrated files.
 *
 * @author huxz
 */
@Entity
@Table(name = "a_migration")
@JsonInclude(Include.NON_EMPTY)
public class MigrationFile {

  @Id
  @GeneratedValue(strategy = GenerationType.AUTO)
  private Long id;

  @Column(name = "old_url", unique = true)
  private String oldUrl;

  @Column(name = "new_url", unique = true)
  private String newUrl;

  @Column(name = "create_time")
  private Date createTime;

  @Column(name = "migrate_time")
  private Date migrateTime;

  @Column(name = "migration_status")
  @Enumerated(EnumType.STRING)
  private FileStatus status;

  @Column(name = "reason", length = 3000)
  private String reason;

  public enum FileStatus {
    CREATED,          // 创建文件迁移记录
    MIGRATED,         // 文件迁移成功
    SYNCHRONIZED      // 同步文件链接成功
  }

  public MigrationFile() {
  }

  public Long getId() {
    return id;
  }

  public void setId(Long id) {
    this.id = id;
  }

  public String getOldUrl() {
    return oldUrl;
  }

  public void setOldUrl(String oldUrl) {
    this.oldUrl = oldUrl;
  }

  public String getNewUrl() {
    return newUrl;
  }

  public void setNewUrl(String newUrl) {
    this.newUrl = newUrl;
  }

  public Date getCreateTime() {
    return createTime;
  }

  public void setCreateTime(Date createTime) {
    this.createTime = createTime;
  }

  public Date getMigrateTime() {
    return migrateTime;
  }

  public void setMigrateTime(Date migrateTime) {
    this.migrateTime = migrateTime;
  }

  public FileStatus getStatus() {
    return status;
  }

  public void setStatus(FileStatus status) {
    this.status = status;
  }

  public String getReason() {
    return reason;
  }

  public void setReason(String reason) {
    this.reason = reason;
  }

  @Override
  public String toString() {
    return JacksonUtils.toJson(this);
  }
}
