package com.uas.platform.oos.migration.entity;

import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonInclude.Include;
import com.uas.platform.oos.core.util.JacksonUtils;
import com.uas.platform.oos.migration.entity.MigrationFile.FileStatus;
import java.util.Date;
import javax.persistence.Column;
import javax.persistence.Entity;
import javax.persistence.EnumType;
import javax.persistence.Enumerated;
import javax.persistence.GeneratedValue;
import javax.persistence.Id;
import javax.persistence.Index;
import javax.persistence.JoinColumn;
import javax.persistence.OneToOne;
import javax.persistence.Table;

/**
 * Record one resource is in multi field of different table.
 *
 * @author huxz
 */
@Entity
@Table(name = "a_resource_to_fields", indexes = {
    @Index(name = "field_resource", columnList = "field_name, migration_id", unique = true)
})
@JsonInclude(Include.NON_EMPTY)
public class ResourceFields {

  @Id
  @GeneratedValue
  private Long id;

  /**
   * Example: tableName.fieldName
   */
  @Column(name = "field_name")
  private String fieldName;

  @OneToOne
  @JoinColumn(name = "migration_id")
  private MigrationFile migration;

  @Column(name = "create_time")
  private Date createTime;

  @Column(name = "mapping_status")
  @Enumerated(EnumType.STRING)
  private FileStatus status;

  public ResourceFields() {
  }

  public Long getId() {
    return id;
  }

  public void setId(Long id) {
    this.id = id;
  }

  public String getFieldName() {
    return fieldName;
  }

  public void setFieldName(String fieldName) {
    this.fieldName = fieldName;
  }

  public MigrationFile getMigration() {
    return migration;
  }

  public void setMigration(MigrationFile migration) {
    this.migration = migration;
  }

  public Date getCreateTime() {
    return createTime;
  }

  public void setCreateTime(Date createTime) {
    this.createTime = createTime;
  }

  public FileStatus getStatus() {
    return status;
  }

  public void setStatus(FileStatus status) {
    this.status = status;
  }

  @Override
  public String toString() {
    return JacksonUtils.toJson(this);
  }
}
